@@ -20,6 +20,7 @@
 import collections
 import functools
 import logging
+import warnings
 import typing as T  # noqa
 
 import xarray as xr  # noqa
@@ -178,6 +179,17 @@ COORD_TRANSLATORS['number'] = functools.partial(
 )
 
 
+# CF-Conventions have no concept of leadtime expressed in months
+def is_forecast_month(coord):
+    # type: (xr.Coordinate) -> bool
+    return coord.attrs.get('long_name') == 'months since forecast_reference_time'
+
+
+COORD_TRANSLATORS['forecastMonth'] = functools.partial(
+    coord_translator, 'forecastMonth', '1', 'increasing', is_forecast_month
+)
+
+
 def translate_coords(
     data, coord_model=COORD_MODEL, errors='warn', coord_translators=COORD_TRANSLATORS
 ):
@@ -192,17 +204,6 @@ def translate_coords(
                 raise RuntimeError("error while translating coordinate: %r" % cf_name)
             else:
                 LOG.warning("error while translating coordinate: %r", cf_name)
-    config = coord_model.get('config', {})
-    if config.get('preferred_time_dimension', 'time') == 'valid_time':
-        try:
-            data = ensure_valid_time(data)
-        except Exception:
-            if errors == 'ignore':
-                pass
-            elif errors == 'raise':
-                raise RuntimeError("error while ensuring valid_time coordinate")
-            else:
-                LOG.exception("error while ensuring valid_time coordinate")
     return data
 
 
@@ -229,6 +230,7 @@ def ensure_valid_time_present(data, valid_time_name='valid_time'):
 
 def ensure_valid_time(data):
     # type: (xr.Dataset) -> xr.Dataset
+    warnings.warn("ensure_valid_time is deprecated use time_dims instead", DeprecationWarning)
     valid_time, time, step = ensure_valid_time_present(data)
     if valid_time not in data.dims:
         if time and time in data.dims and data.coords[time].size == data.coords[valid_time].size:
