@@ -1,5 +1,5 @@
 #
-# Copyright 2017-2018 European Centre for Medium-Range Weather Forecasts (ECMWF).
+# Copyright 2017-2019 European Centre for Medium-Range Weather Forecasts (ECMWF).
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,19 +17,23 @@
 #   Alessandro Amici - B-Open - https://bopen.eu
 #
 
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import typing as T  # noqa
 
 
 PRESSURE_CONVERSION_RULES = {
-    ('Pa', 'pascal', 'pascals'): 1.,
-    ('hPa', 'hectopascal', 'hectopascals', 'hpascal', 'millibar', 'millibars', 'mbar'): 100.,
-    ('decibar', 'dbar'): 10000.,
-    ('bar', 'bars'): 100000.,
-    ('atmosphere', 'atmospheres', 'atm'): 101325.,
+    ('Pa', 'pascal', 'pascals'): 1.0,
+    ('hPa', 'hectopascal', 'hectopascals', 'hpascal', 'millibar', 'millibars', 'mbar'): 100.0,
+    ('decibar', 'dbar'): 10000.0,
+    ('bar', 'bars'): 100000.0,
+    ('atmosphere', 'atmospheres', 'atm'): 101325.0,
 }  # type: T.Dict[T.Tuple, float]
 
+LENGTH_CONVERSION_RULES = {
+    ('m', 'meter', 'meters'): 1.0,
+    ('cm', 'centimeter', 'centimeters'): 0.01,
+    ('km', 'kilometer', 'kilometers'): 1000.0,
+}
+
 
 class ConversionError(Exception):
     pass
@@ -37,7 +41,7 @@ class ConversionError(Exception):
 
 def simple_conversion_factor(source_units, target_units, rules):
     # type: (str, str, T.Dict[T.Tuple, float]) -> float
-    conversion_factor = 1.
+    conversion_factor = 1.0
     seen = 0
     for pressure_units, factor in rules.items():
         if source_units in pressure_units:
@@ -55,7 +59,7 @@ def convert_units(data, target_units, source_units):
     # type: (T.Any, str, str) -> T.Any
     if target_units == source_units:
         return data
-    for rules in [PRESSURE_CONVERSION_RULES]:
+    for rules in [PRESSURE_CONVERSION_RULES, LENGTH_CONVERSION_RULES]:
         try:
             return data * simple_conversion_factor(target_units, source_units, rules)
         except ConversionError:
