@@ -147,7 +147,7 @@ GRID_TYPE_KEYS = sorted(set(k for _, ks in GRID_TYPE_MAP.items() for k in ks))
 ENSEMBLE_KEYS = ['number']
 VERTICAL_KEYS = ['level']
 DATA_TIME_KEYS = ['dataDate', 'dataTime', 'endStep']
-ALL_REF_TIME_KEYS = ['time', 'step', 'valid_time']
+ALL_REF_TIME_KEYS = ['time', 'step', 'valid_time', 'verifying_time', 'forecastMonth']
 SPECTRA_KEYS = ['directionNumber', 'frequencyNumber']
 
 ALL_HEADER_DIMS = ENSEMBLE_KEYS + VERTICAL_KEYS + DATA_TIME_KEYS + ALL_REF_TIME_KEYS + SPECTRA_KEYS
@@ -227,6 +227,16 @@ COORD_ATTRS = {
         'standard_name': 'time',
         'long_name': 'time',
     },
+    'verifying_time': {
+        'units': 'seconds since 1970-01-01T00:00:00',
+        'calendar': 'proleptic_gregorian',
+        'standard_name': 'time',
+        'long_name': 'time',
+    },
+    'forecastMonth': {
+        'units': '1',
+        'long_name': 'months since forecast_reference_time',
+    },
 }
 
 
@@ -252,7 +262,7 @@ def enforce_unique_attributes(index, attributes_keys, filter_by_keys={}):
     return attributes
 
 
-@attr.attrs(cmp=False)
+@attr.attrs(eq=False)
 class Variable(object):
     dimensions = attr.attrib(type=T.Tuple[str, ...])
     data = attr.attrib(type=np.ndarray)
@@ -304,9 +314,6 @@ class OnDiskArray(object):
         return array
 
     def __getitem__(self, item):
-        assert isinstance(item, tuple), "Item type must be tuple not %r" % type(item)
-        assert len(item) == len(self.shape), "Item len must be %r not %r" % (self.shape, len(item))
-
         header_item = expand_item(item[: -self.geo_ndim], self.shape)
         array_field_shape = tuple(len(l) for l in header_item) + self.shape[-self.geo_ndim :]
         array_field = np.full(array_field_shape, fill_value=np.nan, dtype='float32')
@@ -419,7 +426,7 @@ def encode_cf_first(data_var_attrs, encode_cf=('parameter', 'time'), time_dims=(
         if set(time_dims).issubset(ALL_REF_TIME_KEYS):
             coords_map.extend(time_dims)
         else:
-            raise ValueError("time_dims %r not a subset of %r" % (time_dims, ALL_HEADER_DIMS))
+            raise ValueError("time_dims %r not a subset of %r" % (time_dims, ALL_REF_TIME_KEYS))
     else:
         coords_map.extend(DATA_TIME_KEYS)
     coords_map.extend(VERTICAL_KEYS)
@@ -494,10 +501,12 @@ def build_variable_components(
         geo_ndim=len(geo_dims),
     )
 
-    if 'time' in coord_vars and 'valid_time' not in coord_vars and 'time' in encode_cf:
+    if 'time' in coord_vars and 'step' in coord_vars:
         # add the 'valid_time' secondary coordinate
-        step_data = coord_vars['step'].data if 'step' in coord_vars else np.array(0.0)
-        dims, time_data = cfmessage.build_valid_time(coord_vars['time'].data, step_data)
+        dims, time_data = cfmessage.build_valid_time(
+            coord_vars['time'].data,
+            coord_vars['step'].data,
+        )
         attrs = COORD_ATTRS['valid_time']
         coord_vars['valid_time'] = Variable(dimensions=dims, data=time_data, attributes=attrs)
 
@@ -520,11 +529,29 @@ def dict_merge(master, update):
             )
 
 
+def build_dataset_attributes(index, filter_by_keys, encoding):
+    attributes = enforce_unique_attributes(index, GLOBAL_ATTRIBUTES_KEYS, filter_by_keys)
+    attributes['Conventions'] = 'CF-1.7'
+    if 'GRIB_centreDescription' in attributes:
+        attributes['institution'] = attributes['GRIB_centreDescription']
+    attributes_namespace = {
+        'cfgrib_version': __version__,
+        'cfgrib_open_kwargs': json.dumps(encoding),
+        'eccodes_version': messages.eccodes_version,
+        'timestamp': datetime.datetime.now().isoformat().partition('.')[0],
+    }
+    history_in = (
+        '{timestamp} GRIB to CDM+CF via '
+        'cfgrib-{cfgrib_version}/ecCodes-{eccodes_version} with {cfgrib_open_kwargs}'
+    )
+    attributes['history'] = history_in.format(**attributes_namespace)
+    return attributes
+
+
 def build_dataset_components(
     index,
     errors='warn',
     encode_cf=('parameter', 'time', 'geography', 'vertical'),
-    timestamp=None,
     squeeze=True,
     log=LOG,
     read_keys=[],
@@ -535,9 +562,6 @@ def build_dataset_components(
     filter_by_keys = index.filter_by_keys
     for param_id in index['paramId']:
         var_index = index.subindex(paramId=param_id)
-        first = var_index.first()
-        short_name = first['shortName']
-        var_name = first['cfVarName']
         try:
             dims, data_var, coord_vars = build_variable_components(
                 var_index,
@@ -560,6 +584,8 @@ def build_dataset_components(
                 fbks.append(fbk)
                 error_message += "\n    filter_by_keys=%r" % fbk
             raise DatasetBuildError(error_message, key, fbks)
+        short_name = data_var.attributes.get('GRIB_shortName', 'paramId_%d' % param_id)
+        var_name = data_var.attributes.get('GRIB_cfVarName', 'unknown')
         if 'parameter' in encode_cf and var_name not in ('undef', 'unknown'):
             short_name = var_name
         try:
@@ -573,25 +599,12 @@ def build_dataset_components(
                 raise
             else:
                 log.exception("skipping variable: paramId==%r shortName=%r", param_id, short_name)
-    attributes = enforce_unique_attributes(index, GLOBAL_ATTRIBUTES_KEYS, filter_by_keys)
     encoding = {
         'source': index.filestream.path,
         'filter_by_keys': filter_by_keys,
         'encode_cf': encode_cf,
     }
-    attributes['Conventions'] = 'CF-1.7'
-    attributes['institution'] = attributes['GRIB_centreDescription']
-    attributes_namespace = {
-        'cfgrib_version': __version__,
-        'cfgrib_open_kwargs': json.dumps(encoding),
-        'eccodes_version': messages.eccodes_version,
-        'timestamp': timestamp or datetime.datetime.now().isoformat().partition('.')[0],
-    }
-    history_in = (
-        '{timestamp} GRIB to CDM+CF via '
-        'cfgrib-{cfgrib_version}/ecCodes-{eccodes_version} with {cfgrib_open_kwargs}'
-    )
-    attributes['history'] = history_in.format(**attributes_namespace)
+    attributes = build_dataset_attributes(index, filter_by_keys, encoding)
     return dimensions, variables, attributes, encoding
 
 
